@@ -33,6 +33,9 @@ OC.L10N.register(
     "Open your browser console for more details" : "Отворете ја конзолата на прелистувачот за повеќе детали",
     "Last modified" : "Скоро изменети",
     "Priority" : "Приоритет",
+    "[Yesterday]" : "[Вчера]",
+    "[Today]" : "[Денес]",
+    "[Tomorrow]" : "[Утре]",
     "Tomorrow" : "Утре",
     "Set start date" : "Постави почетен датум",
     "Set due date" : "Постави краен рок",
